# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..1\n"; }
END {print "not ok 1\n" unless $loaded;}
use Palm::DiabetesPilot;
$loaded = 1;
print "ok 1\n";

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

use Palm::PDB;

my $pdb = new Palm::PDB;

exit 0 unless -f "$ENV{HOME}/.palm/backup/Diabetes Pilot Data.pdb";

$pdb->Load( "$ENV{HOME}/.palm/backup/Diabetes Pilot Data.pdb" );

for( @{$pdb->{records}} ) {
	printf "%04d-%02d-%02d %02d:%02d %-17s ",
		$_->{'year'}, $_->{'month'}, $_->{'day'}, $_->{'hour'}, $_->{'minute'},
		$pdb->{appinfo}{categories}[$_->{category}]{name};
	print $_->{'type'}, "\n";
}

exit 0;
